@@ -17,25 +17,23 @@
 #'
 #' @return Returns the complete output of the exploratory analysis: i) The processed, or filtered/normalized data ii) Statistical output containing results for the parametric (limma+ANOVA) and non-parametric tests (Wilcoxon_p_+Kruskal-Wallis+PERMANOVA), along with statistical tests for heteroscedasticity, iii) Quality metrics for the input samples iv) QC plots and exploratory visualizations.
 #' @importFrom openxlsx write.xlsx  read.xlsx
-#' @importFrom grDevices  dev.off bmp
-#' @importFrom circlize colorRamp2
+#' @importFrom grDevices  dev.off bmp colorRampPalette
 #' @importFrom dplyr select  group_by  group_modify everything  %>% any_of
 #' @importFrom tidyr gather pivot_longer
 #' @importFrom broom tidy
 #' @importFrom reshape2 melt
 #' @importFrom ggpubr ggarrange
-#' @importFrom ggplot2 ggplot ggsave geom_violin  scale_x_discrete scale_color_gradient element_line theme_linedraw scale_fill_manual scale_color_manual aes geom_histogram element_rect geom_point xlab ylab ggtitle theme_bw theme_minimal theme element_text guides guide_legend geom_boxplot labs theme_classic element_blank geom_jitter position_jitter
+#' @importFrom ggplot2 ggplot ggsave geom_violin  scale_x_discrete scale_color_gradient element_line theme_linedraw scale_fill_manual scale_color_manual aes geom_histogram element_rect geom_point geom_smooth xlab ylab ggtitle theme_bw theme_minimal theme element_text guides guide_legend geom_boxplot labs theme_classic element_blank geom_jitter position_jitter
 #' @importFrom VIM kNN
 #' @importFrom stats kruskal.test p.adjust prcomp sd wilcox.test friedman.test rnorm bartlett.test model.matrix heatmap median na.omit
 #' @importFrom forcats fct_inorder
 #' @importFrom limma topTable eBayes contrasts.fit normalizeCyclicLoess normalizeVSN lmFit normalizeQuantiles duplicateCorrelation
-#' @importFrom ComplexHeatmap HeatmapAnnotation anno_block draw Heatmap
 #' @importFrom grid gpar
-#' @importFrom UniProt.ws mapUniProt
+#' @importFrom pheatmap pheatmap
+#' @importFrom UniprotR GetProteinAnnontate
 #' @importFrom stringr str_extract
 #' @importFrom missRanger missRanger
 #' @importFrom car leveneTest
-#' @importFrom vsn meanSdPlot
 #' @importFrom utils read.delim2
 #' @importFrom vegan adonis2
 #'
@@ -44,9 +42,14 @@
 #' # The file path is a placeholder, replace it with an actual file.
 #'
 #' jittered.pg_matrix.tsv <- system.file("extdata", "report.pg_matrix.tsv", package = "ProtE")
-#' dianno(file = jittered.pg_matrix.tsv,
+#'
+#' # Copy the file to a temporary directory for CRAN checks
+#' temp_file <- file.path(tempdir(), "report.pg_matrix.tsv")
+#' file.copy(jittered.pg_matrix.tsv, temp_file, overwrite = TRUE)
+#'
+#' dianno(file = temp_file,
 #'        group_names = c("Healthy","Control"),
-#'        samples_per_group = c(5,5), filtering_value = 80)
+#'        samples_per_group = c(5,4), filtering_value = 80)
 #'
 #' @export
 
@@ -62,16 +65,19 @@ dianno <- function(file,
                    significance  = "p", description = FALSE)
 {message("The ProtE process starts now!")
 
-  Protein.Ids =Protein.Names =Symbol =X =Y = Description = df4_wide= percentage=Sample= Genes = variable =.=key=Accession =value =g1.name=g2.name= NULL
+  Protein.Ids =Protein.Names =Symbol =X =Y = Mean = SD = Description = df4_wide= percentage=Sample= Genes = variable =.=key=Accession =value =g1.name=g2.name= NULL
 groups_number <- length(group_names)
  if (length(samples_per_group) != groups_number) {
     stop("The length of 'samples_per_group' must be equal to the length of 'group_names'. Each of the numerical values in 'samples_per_group' must denote the sample size for the corresponding group in 'group_names") }
 
   for (i in 1:groups_number) {
     assign(paste0("g",i,".name"),group_names[[i]])}
-
+if(grepl("\\.tsv$", file)) {
   dataspace <- utils::read.delim2(file, header = TRUE, sep = "\t")
-
+}
+else if(grepl("\\.xlsx$", file)) {
+  dataspace <- openxlsx::read.xlsx(file)
+} else {stop("Error, the file you provided is not on .tsv or .xlsx format")}
 
   path <- dirname(file)
   path_res <- file.path(path , "ProtE_Analysis")
@@ -104,24 +110,10 @@ if (description == TRUE ) {
   id_numbers <- dataspace$Protein.Ids
   for (j in 1:length(id_numbers)){id_numbers[j] <- stringr::str_extract(id_numbers[j], "^[^;]*")}
   df_description <- data.frame("Description" = character(), stringsAsFactors = FALSE)
-  metadata<-UniProt.ws::mapUniProt( from = "UniProtKB_AC-ID", to = "UniProtKB", columns = c("protein_name","organism_name","gene_names","protein_existence","sequence_version","id"), id_numbers,pageSize = 500L)
-  df_number_ids<-as.data.frame(id_numbers)
-  fixed_data<-dplyr::left_join(df_number_ids,metadata,by=c("id_numbers"="From"))
-
-  for (i in 1:nrow( fixed_data)){
-    organism<- fixed_data$Organism[i]
-    gene<-stringr::str_extract(fixed_data$Gene.Names[i], "^[^ ]*")
-    entry_name<- fixed_data$Entry.Name[i]
-    protein_name<- fixed_data$Protein.names[i]
-    sv<- fixed_data$Sequence.version[i]
-    if (fixed_data$Protein.existence[i]=="Evidence at protein level"){pe<-1}
-    if (fixed_data$Protein.existence[i]=="Evidence at transcript level"){pe<-2}
-    if (fixed_data$Protein.existence[i]=="Inferred by homology"){pe<-3}
-    if (fixed_data$Protein.existence[i]=="Predicted") {pe<-4}
-    if (fixed_data$Protein.existence[i]=="Uncertain") {pe<-5}
-    details<-paste(protein_name," OS=",organism," GN=",gene," PE=",pe," SV=",sv," -[",entry_name,"]")
-    df_description <- rbind(df_description, data.frame(Description = details, stringsAsFactors = FALSE))
-  }
+  dataspace$Protein.Ids<-id_numbers
+  conv_ID <- GetProteinAnnontate(dataspace$Protein.Ids, columns =c("organism_name"	, "protein_name"	, "id"	,"gene_names") )
+  details<-paste(conv_ID$Protein.names," OS=",conv_ID$Organism," GN=",conv_ID$Gene.Names," -[",conv_ID$Entry.Name,"]")
+  df_description <- rbind(df_description, data.frame(Description = details, stringsAsFactors = FALSE))
 
   dataspace<-cbind(dataspace[,1:2],df_description,dataspace[,3:ncol(dataspace)])
   colnames(dataspace)[colnames(dataspace) == "Protein.Ids"] <- "Accession"
@@ -140,7 +132,7 @@ if (description == TRUE ) {
     colnames(dataspace) <- col_names
     dataspace <- dataspace[rowSums(!is.na(dataspace[,-1])) > 0, ]
 
-      dataspace$Description = "Not Available"
+      dataspace$Description <- rep("Not Available", nrow(dataspace))
     dataspace<-dataspace %>%
       dplyr::select(Genes,any_of(c("Protein.Names","Description")) , everything())
     message("The description fetching is not available when the input is a unique_genes matrix")
@@ -166,12 +158,7 @@ if (description == TRUE ) {
     })
 
     Gdataspace<-dataspace
-    Gdataspace$Symbol = sub(".*GN=(.*?) .*","\\1",Gdataspace$Description)
-    Gdataspace$Symbol[Gdataspace$Symbol==Gdataspace$Description] = "Not available"
-    Gdataspace<-Gdataspace %>%
-      dplyr::select(Accession, Description, Symbol, everything())
-    colnames(Gdataspace) <- gsub(".xlsx", "", colnames(Gdataspace))
-    norm_file_path <- file.path(path_resman, "Normalized.xlsx")
+   norm_file_path <- file.path(path_resman, "Normalized.xlsx")
     openxlsx::write.xlsx(Gdataspace, file = norm_file_path)
     message("Applying the selected normalization, saved as Normalized.xlsx")}
 
@@ -179,34 +166,19 @@ if (description == TRUE ) {
     dataspace[, -1:-2] <- log(dataspace[, -1:-2]+1,2)
     dataspace[, -1:-2] <- limma::normalizeQuantiles(dataspace[, -1:-2])
     Gdataspace<-dataspace
-    Gdataspace$Symbol = sub(".*GN=(.*?) .*","\\1",Gdataspace$Description)
-    Gdataspace$Symbol[Gdataspace$Symbol==Gdataspace$Description] = "Not available"
-    Gdataspace<-Gdataspace %>%
-      dplyr::select(Accession, Description, Symbol, everything())
-    colnames(Gdataspace) <- gsub(".xlsx", "", colnames(Gdataspace))
-    norm_file_path <- file.path(path_resman, "Normalized.xlsx")
+   norm_file_path <- file.path(path_resman, "Normalized.xlsx")
     openxlsx::write.xlsx(Gdataspace, file = norm_file_path)
     message("Applying the selected normalization, saved as Normalized.xlsx") }
   if (normalization == "log2"){
     dataspace[, -1:-2] <- log(dataspace[, -1:-2]+1,2)
     Gdataspace<-dataspace
-    Gdataspace$Symbol = sub(".*GN=(.*?) .*","\\1",Gdataspace$Description)
-    Gdataspace$Symbol[Gdataspace$Symbol==Gdataspace$Description] = "Not available"
-    Gdataspace<-Gdataspace %>%
-      dplyr::select(Accession, Description, Symbol, everything())
-    colnames(Gdataspace) <- gsub(".xlsx", "", colnames(Gdataspace))
-    norm_file_path <- file.path(path_resman, "Normalized.xlsx")
+   norm_file_path <- file.path(path_resman, "Normalized.xlsx")
     openxlsx::write.xlsx(Gdataspace, file = norm_file_path)
     message("Applying the selected normalization, saved as Normalized.xlsx") }
   if (normalization == "Total_Ion_Current") {
     dataspace[, -1:-2] <- lapply(dataspace[, -1:-2], function(x) (x / sum(x, na.rm = TRUE)) * mean(colSums(dataspace[, -1:-2], na.rm = TRUE)))
     Gdataspace<-dataspace
-    Gdataspace$Symbol = sub(".*GN=(.*?) .*","\\1",Gdataspace$Description)
-    Gdataspace$Symbol[Gdataspace$Symbol==Gdataspace$Description] = "Not available"
-    Gdataspace<-Gdataspace %>%
-      dplyr::select(Accession, Description, Symbol, everything())
-    colnames(Gdataspace) <- gsub(".xlsx", "", colnames(Gdataspace))
-    norm_file_path <- file.path(path_resman, "Normalized.xlsx")
+     norm_file_path <- file.path(path_resman, "Normalized.xlsx")
     openxlsx::write.xlsx(Gdataspace, file = norm_file_path)
     message("Applying the selected normalization, saved as Normalized.xlsx")}
 
@@ -214,11 +186,6 @@ if (description == TRUE ) {
     dataspace[, -1:-2] <- log(dataspace[, -1:-2]+1,2)
     dataspace[, -1:-2] <- limma::normalizeCyclicLoess(dataspace[, -1:-2])
     Gdataspace<-dataspace
-    Gdataspace$Symbol = sub(".*GN=(.*?) .*","\\1",Gdataspace$Description)
-    Gdataspace$Symbol[Gdataspace$Symbol==Gdataspace$Description] = "Not available"
-    Gdataspace<-Gdataspace %>%
-      dplyr::select(Accession, Description, Symbol, everything())
-    colnames(Gdataspace) <- gsub(".xlsx", "", colnames(Gdataspace))
     norm_file_path <- file.path(path_resman, "Normalized.xlsx")
     openxlsx::write.xlsx(Gdataspace, file = norm_file_path)
     message("Applying the selected normalization, saved as Normalized.xlsx") }
@@ -226,12 +193,7 @@ if (description == TRUE ) {
   if ( normalization == "VSN") {
     dataspace[, -1:-2] <- suppressMessages(limma::normalizeVSN(dataspace[, -1:-2]))
     Gdataspace<-dataspace
-    Gdataspace$Symbol = sub(".*GN=(.*?) .*","\\1",Gdataspace$Description)
-    Gdataspace$Symbol[Gdataspace$Symbol==Gdataspace$Description] = "Not available"
-    Gdataspace<-Gdataspace %>%
-      dplyr::select(Accession, Description, Symbol, everything())
-    colnames(Gdataspace) <- gsub(".xlsx", "", colnames(Gdataspace))
-    norm_file_path <- file.path(path_resman, "Normalized.xlsx")
+     norm_file_path <- file.path(path_resman, "Normalized.xlsx")
     openxlsx::write.xlsx(Gdataspace, file = norm_file_path)
     message("Applying the selected normalization, saved as Normalized.xlsx")
   }
@@ -239,31 +201,44 @@ if (description == TRUE ) {
     sample_medians <- apply(dataspace[, -1:-2], 2, median, na.rm = TRUE)
     dataspace[, -1:-2] <- sweep(dataspace[, -1:-2], 2, sample_medians, FUN = "/")
     Gdataspace<-dataspace
-    Gdataspace$Symbol = sub(".*GN=(.*?) .*","\\1",Gdataspace$Description)
-    Gdataspace$Symbol[Gdataspace$Symbol==Gdataspace$Description] = "Not available"
-    Gdataspace<-Gdataspace %>%
-      dplyr::select(Accession, Description, Symbol, everything())
-    colnames(Gdataspace) <- gsub(".xlsx", "", colnames(Gdataspace))
     norm_file_path <- file.path(path_resman, "Normalized.xlsx")
     openxlsx::write.xlsx(Gdataspace, file = norm_file_path)
     message("Applying the selected normalization, saved as Normalized.xlsx")}
 
   if (normalization %in% c(FALSE,"median", "Total_Ion_Current", "PPM") ){
     log.dataspace <- log(dataspace[,-c(1:2)]+1,2)
-    sdrankplot_path <- file.path(path_resplot, "meanSdPlot.bmp")
-    bmp(sdrankplot_path,width = 1500, height = 1080, res = 150)
-    suppressWarnings(vsn::meanSdPlot(as.matrix(log.dataspace[, -1:-2])))
-    dev.off()
+    row_means <- rowMeans(log.dataspace, na.rm = TRUE)
+    row_sds <- apply(log.dataspace, 1, sd, na.rm = TRUE)
+    plot_data <- data.frame(Mean = row_means, SD = row_sds)
+    meansd <- ggplot(plot_data, aes(x = Mean, y = SD)) +
+      geom_point(alpha = 0.5, color = "blue") +
+      geom_smooth(method = "loess", color = "red", se = FALSE) +
+      theme_minimal() +
+      labs(title = "Mean-SD Plot on the log2 normalized data", x = "Mean Expression", y = "Standard Deviation")
+    meansd
+    ggplot2::ggsave("meanSdPlot.bmp", plot = meansd,  path = path_resplot,
+                    scale = 1, width = 5, height = 4, units = "in",
+                    dpi = 300, limitsize = TRUE)
+
     message("Creating Mean-SD plot on the log2 data.")
   } else {
-    sdrankplot_path <- file.path(path_resplot, "meanSdPlot.bmp")
-    bmp(sdrankplot_path,width = 1500, height = 1080, res = 150)
-    suppressWarnings(vsn::meanSdPlot(as.matrix(dataspace[, -1:-2])))
-    dev.off()
+    row_means <- rowMeans(dataspace[,-c(1,2)], na.rm = TRUE)
+    row_sds <- apply(dataspace[,-c(1,2)], 1, sd, na.rm = TRUE)
+    plot_data <- data.frame(Mean = row_means, SD = row_sds)
+    meansd <- ggplot(plot_data, aes(x = Mean, y = SD)) +
+      geom_point(alpha = 0.5, color = "blue") +
+      suppressMessages(geom_smooth(method = "loess", color = "red", se = FALSE)) +
+      theme_minimal() +
+      labs(title = "Mean-SD Plot on the log2 normalized data", x = "Mean Expression", y = "Standard Deviation")
+    meansd
+    ggplot2::ggsave("meanSdPlot.bmp", plot = meansd,  path = path_resplot,
+                    scale = 1, width = 5, height = 4, units = "in",
+                    dpi = 300, limitsize = TRUE)
     message("Creating Mean-SD plot.")
   }
 
 
+
   if (filtering_value < 0 && filtering_value > 100) {stop("Error: The filtering_value must be a number ranging from 0 to 100")}
 
   if (global_filtering == TRUE) {
@@ -640,7 +615,7 @@ anova_res<- anova_res[,-c(1:groups_number)]}
   metadata2 <- data.frame(group = groups_list_u)
   rownames(transposed_data) <- metadata2$group
   metadata2$samples <- colnames(only.data)
-  adonis2_results <- vegan::adonis2(transposed_data ~ group, data = metadata2, method = "bray", permutations = 999)
+  adonis2_results <- vegan::adonis2(transposed_data ~ group, data = metadata2, method = "bray", na.rm = TRUE, permutations = 999)
   permanova_psF <- adonis2_results[4]
   permanova_psF<- permanova_psF[-c(2:3),]
   permanova_pValue <- adonis2_results[5]
@@ -851,29 +826,28 @@ anova_res<- anova_res[,-c(1:groups_number)]}
  zlog.dataspace.sig <- zlog.dataspace.sig[,order(groups_list_f)]
 
  range_limit <- min(abs(min(zlog.dataspace.sig, na.rm = TRUE)), abs(max(zlog.dataspace.sig, na.rm = TRUE)))
+ breaks <- seq(-range_limit, range_limit, length.out = 101)
+ mycols_vector <- grDevices::colorRampPalette(c("blue", "white", "red"))(100)
 
- mycols <- circlize::colorRamp2(
-   c(-range_limit, 0, range_limit),
-   c("blue", "white", "red")
- )
- heatmap_data<- ComplexHeatmap::Heatmap(as.matrix(zlog.dataspace.sig),
-                                           cluster_rows = TRUE,
-                                           cluster_columns = FALSE,
-                                           show_row_names = FALSE,
-                                           show_column_names = FALSE,
-                                           column_split = groups_list_f,
-                                           top_annotation = ComplexHeatmap::HeatmapAnnotation(foo = anno_block(gp = gpar(fill = 2:(groups_number+1)),
-                                                                                                               labels = group_names, labels_gp = gpar(col = "white", fontsize = 10))),
-                                           col = mycols, column_title = NULL,
-                                           heatmap_legend_param = list(
-                                             title = "Z-Score",
-                                             color_bar = "continuous"
-                                           ))
-    bmp_file_path <- file.path(path_resplot, "heatmap.bmp")
-    bmp(bmp_file_path,width = 1500, height = 1080, res = 150)
-    ComplexHeatmap::draw(heatmap_data)
-    dev.off()
-    message("A heatmap with the differentially expressed proteins was created as heatmap.bmp")
+ annotation_col <- data.frame(Group = factor(groups_list_f))
+ rownames(annotation_col) <- colnames(zlog.dataspace.sig)
+ colnames(annotation_col) <- " "
+ bmp_file_path <- file.path(path_resplot, "heatmap.bmp")
+ bmp(bmp_file_path,width = 1500, height = 1080, res = 150)
+ pheatmap(as.matrix(zlog.dataspace.sig),
+          cluster_rows = TRUE,
+          cluster_cols = FALSE,
+          show_rownames = FALSE,
+          show_colnames = FALSE,
+          annotation_col = annotation_col,
+          color = mycols_vector,
+          breaks = breaks,
+          legend = TRUE,
+          legend_labels = NULL,
+          annotation_legend = TRUE,
+          scale = "none")
+ dev.off()
+ message("A heatmap with the differentially expressed proteins was created as heatmap.bmp")
 
 
     pca<-prcomp(t(log.dataspace.sig), scale=TRUE, center=TRUE)
