@@ -16,26 +16,24 @@
 #'
 #' @return Returns the complete output of the exploratory analysis: i) The processed, or filtered/normalized data ii) Statistical output containing results for the parametric (limma+ANOVA) and non-parametric tests (Wilcoxon+Kruskal-Wallis+PERMANOVA), along with statistical tests for heteroscedasticity, iii) Quality metrics for the input samples iv) QC plots and exploratory visualizations.
 #' @importFrom openxlsx write.xlsx  read.xlsx
-#' @importFrom grDevices  dev.off bmp
-#' @importFrom circlize colorRamp2
+#' @importFrom grDevices  dev.off bmp colorRampPalette
 #' @importFrom vegan adonis2
 #' @importFrom dplyr select  group_by  group_modify everything  %>%
 #' @importFrom tidyr gather pivot_longer
 #' @importFrom broom tidy
 #' @importFrom reshape2 melt
 #' @importFrom ggpubr ggarrange
-#' @importFrom ggplot2 ggplot ggsave geom_violin scale_color_gradient element_line theme_linedraw scale_fill_manual scale_color_manual aes geom_histogram element_rect geom_point xlab ylab ggtitle theme_bw theme_minimal theme element_text guides guide_legend geom_boxplot labs theme_classic element_blank geom_jitter position_jitter
+#' @importFrom ggplot2 ggplot ggsave geom_smooth geom_violin scale_color_gradient element_line theme_linedraw scale_fill_manual scale_color_manual aes geom_histogram element_rect geom_point xlab ylab ggtitle theme_bw theme_minimal theme element_text guides guide_legend geom_boxplot labs theme_classic element_blank geom_jitter position_jitter
 #' @importFrom VIM kNN
-#' @importFrom UniProt.ws mapUniProt
+#' @importFrom UniprotR GetProteinAnnontate
 #' @importFrom stringr str_extract
 #' @importFrom stats kruskal.test p.adjust prcomp sd wilcox.test friedman.test rnorm bartlett.test model.matrix heatmap median na.omit
 #' @importFrom forcats fct_inorder
 #' @importFrom limma topTable eBayes contrasts.fit  normalizeCyclicLoess lmFit normalizeQuantiles duplicateCorrelation
-#' @importFrom ComplexHeatmap HeatmapAnnotation anno_block draw Heatmap
+#' @importFrom pheatmap pheatmap
 #' @importFrom grid gpar
 #' @importFrom missRanger missRanger
 #' @importFrom car leveneTest
-#' @importFrom vsn meanSdPlot
 #'
 #'
 #'
@@ -44,7 +42,12 @@
 #' # The file path is a placeholder, replace it with an actual file.
 #'
 #' PDconsesus_file.xlsx <- system.file("extdata", "PDconsesus_file.xlsx", package = "ProtE")
-#' pd_single(file = PDconsesus_file.xlsx,
+#'
+#' # Copy the file to a temporary directory for CRAN checks
+#' temp_file <- file.path(tempdir(), "PDconsesus_file.xlsx")
+#' file.copy(PDconsesus_file.xlsx, temp_file, overwrite = TRUE)
+#'
+#' pd_single(file = temp_file,
 #'        group_names = c("Healthy","Control"),
 #'        samples_per_group = c(4,4), filtering_value = 80)
 #' @export
@@ -61,7 +64,7 @@ pd_single <- function(file,
                         significance = "p",
                       description = FALSE)
 {
-  group1 = group2 = Accession =Description =Symbol =X =Y = df4_wide= percentage=Sample= variable =.= g1.name =g2.name= g3.name =g4.name= g5.name =g6.name= g7.name= g8.name =g9.name =group3= group4= group5= group6 =group7= group8= group9 =key =value = NULL
+  group1 = group2 = Accession =Description =Mean = SD = Symbol =X =Y = df4_wide= percentage=Sample= variable =.= g1.name =g2.name= g3.name =g4.name= g5.name =g6.name= g7.name= g8.name =g9.name =group3= group4= group5= group6 =group7= group8= group9 =key =value = NULL
 
 message("The ProtE process starts now")
 
@@ -71,8 +74,9 @@ message("The ProtE process starts now")
 
   for (i in 1:groups_number) {
     assign(paste0("g",i,".name"),group_names[[i]])}
-
- dataspace <- openxlsx::read.xlsx(file)
+ if(grepl("\\.xlsx$", file)) {
+    dataspace <- openxlsx::read.xlsx(file)
+  } else {stop("Error, the file you provided is not on .txt or .xlsx format")}
 
    path <- dirname(file)
   path_res <- file.path(path , "ProtE_Analysis")
@@ -102,27 +106,13 @@ if ("Description" %in% colnames(dataspace)){
   }
   if (description == TRUE){
     "The Description fetching from UniProt starts now, it might take some time depending on you Network speed."
-    id_numbers <- dataspace$Accession
+    id_numbers <- dataspace$Protein.Ids
     for (j in 1:length(id_numbers)){id_numbers[j] <- stringr::str_extract(id_numbers[j], "^[^;]*")}
     df_description <- data.frame("Description" = character(), stringsAsFactors = FALSE)
-    metadata<-UniProt.ws::mapUniProt( from = "UniProtKB_AC-ID", to = "UniProtKB", columns = c("protein_name","organism_name","gene_names","protein_existence","sequence_version","id"), id_numbers,pageSize = 500L)
-    df_number_ids<-as.data.frame(id_numbers)
-    fixed_data<-dplyr::left_join(df_number_ids,metadata,by=c("id_numbers"="From"))
-
-    for (i in 1:nrow( fixed_data)){
-      organism<- fixed_data$Organism[i]
-      gene<-stringr::str_extract(fixed_data$Gene.Names[i], "^[^ ]*")
-      entry_name<- fixed_data$Entry.Name[i]
-      protein_name<- fixed_data$Protein.names[i]
-      sv<- fixed_data$Sequence.version[i]
-      if (fixed_data$Protein.existence[i]=="Evidence at protein level"){pe<-1}
-      if (fixed_data$Protein.existence[i]=="Evidence at transcript level"){pe<-2}
-      if (fixed_data$Protein.existence[i]=="Inferred by homology"){pe<-3}
-      if (fixed_data$Protein.existence[i]=="Predicted") {pe<-4}
-      if (fixed_data$Protein.existence[i]=="Uncertain") {pe<-5}
-      details<-paste(protein_name," OS=",organism," GN=",gene," PE=",pe," SV=",sv," -[",entry_name,"]")
-      df_description <- rbind(df_description, data.frame(Description = details, stringsAsFactors = FALSE))
-    }
+    dataspace$Protein.Ids<-id_numbers
+    conv_ID <- GetProteinAnnontate(dataspace$Protein.Ids, columns =c("organism_name"	, "protein_name"	, "id"	,"gene_names") )
+    details<-paste(conv_ID$Protein.names," OS=",conv_ID$Organism," GN=",conv_ID$Gene.Names," -[",conv_ID$Entry.Name,"]")
+    df_description <- rbind(df_description, data.frame(Description = details, stringsAsFactors = FALSE))
 
     dataspace<-cbind(dataspace[,1],df_description,dataspace[,2:ncol(dataspace)])
   }
@@ -227,16 +217,33 @@ if (normalization == "median") {
 
 if (normalization %in% c(FALSE,"median", "Total_Ion_Current", "PPM") ){
   log.dataspace <- log(dataspace[,-c(1:2)]+1,2)
-sdrankplot_path <- file.path(path_resplot, "meanSdPlot.bmp")
-  bmp(sdrankplot_path,width = 1500, height = 1080, res = 150)
-  suppressWarnings(vsn::meanSdPlot(as.matrix(log.dataspace[, -1:-2])))
-  dev.off()
+  row_means <- rowMeans(log.dataspace, na.rm = TRUE)
+  row_sds <- apply(log.dataspace, 1, sd, na.rm = TRUE)
+  plot_data <- data.frame(Mean = row_means, SD = row_sds)
+  meansd <- ggplot(plot_data, aes(x = Mean, y = SD)) +
+    geom_point(alpha = 0.5, color = "blue") +
+    suppressMessages(geom_smooth(method = "loess", color = "red", se = FALSE)) +
+    theme_minimal() +
+    labs(title = "Mean-SD Plot on the log2 normalized data", x = "Mean Expression", y = "Standard Deviation")
+  meansd
+  ggplot2::ggsave("meanSdPlot.bmp", plot = meansd,  path = path_resplot,
+                  scale = 1, width = 5, height = 4, units = "in",
+                  dpi = 300, limitsize = TRUE)
+
   message("Creating Mean-SD plot on the log2 data.")
 } else {
-  sdrankplot_path <- file.path(path_resplot, "meanSdPlot.bmp")
-  bmp(sdrankplot_path,width = 1500, height = 1080, res = 150)
-  suppressWarnings(vsn::meanSdPlot(as.matrix(dataspace[, -1:-2])))
-  dev.off()
+  row_means <- rowMeans(dataspace[,-c(1,2)], na.rm = TRUE)
+  row_sds <- apply(dataspace[,-c(1,2)], 1, sd, na.rm = TRUE)
+  plot_data <- data.frame(Mean = row_means, SD = row_sds)
+  meansd <- ggplot(plot_data, aes(x = Mean, y = SD)) +
+    geom_point(alpha = 0.5, color = "blue") +
+    geom_smooth(method = "loess", color = "red", se = FALSE) +
+    theme_minimal() +
+    labs(title = "Mean-SD Plot on the log2 normalized data", x = "Mean Expression", y = "Standard Deviation")
+  meansd
+  ggplot2::ggsave("meanSdPlot.bmp", plot = meansd,  path = path_resplot,
+                  scale = 1, width = 5, height = 4, units = "in",
+                  dpi = 300, limitsize = TRUE)
   message("Creating Mean-SD plot.")
 }
 
@@ -805,26 +812,26 @@ if (length(which.sig) <2){
 
     range_limit <- min(abs(min(zlog.dataspace.sig, na.rm = TRUE)), abs(max(zlog.dataspace.sig, na.rm = TRUE)))
 
-    mycols <- circlize::colorRamp2(
-      c(-range_limit, 0, range_limit),
-      c("blue", "white", "red")
-    )
-    heatmap_data<- ComplexHeatmap::Heatmap(as.matrix(zlog.dataspace.sig),
-                                           cluster_rows = TRUE,
-                                           cluster_columns = FALSE,
-                                           show_row_names = FALSE,
-                                           show_column_names = FALSE,
-                                           column_split = groups_list_f,
-                                           top_annotation = ComplexHeatmap::HeatmapAnnotation(foo = anno_block(gp = gpar(fill = 2:(groups_number+1)),
-                                                                                                               labels = group_names, labels_gp = gpar(col = "black", fontsize = 10))),
-                                           col = mycols, column_title = NULL,
-                                           heatmap_legend_param = list(
-                                             title = "Z-Score",
-                                             color_bar = "continuous"
-                                           ))
+    breaks <- seq(-range_limit, range_limit, length.out = 101)
+    mycols_vector <- grDevices::colorRampPalette(c("blue", "white", "red"))(100)
+
+    annotation_col <- data.frame(Group = factor(groups_list_f))
+    rownames(annotation_col) <- colnames(zlog.dataspace.sig)
+    colnames(annotation_col) <- " "
     bmp_file_path <- file.path(path_resplot, "heatmap.bmp")
     bmp(bmp_file_path,width = 1500, height = 1080, res = 150)
-    ComplexHeatmap::draw(heatmap_data)
+    pheatmap(as.matrix(zlog.dataspace.sig),
+             cluster_rows = TRUE,
+             cluster_cols = FALSE,
+             show_rownames = FALSE,
+             show_colnames = FALSE,
+             annotation_col = annotation_col,
+             color = mycols_vector,
+             breaks = breaks,
+             legend = TRUE,
+             legend_labels = NULL,
+             annotation_legend = TRUE,
+             scale = "none")
     dev.off()
 
     message("A heatmap with the differentially expressed proteins was created as heatmap.bmp")
