@@ -20,32 +20,45 @@
 #' @importFrom tidyr gather pivot_longer
 #' @importFrom broom tidy
 #' @importFrom grid gpar
-#' @importFrom grDevices  dev.off bmp
-#' @importFrom circlize colorRamp2
+#' @importFrom grDevices  dev.off bmp colorRampPalette
 #' @importFrom reshape2 melt
 #' @importFrom ggpubr ggarrange
-#' @importFrom ggplot2 ggplot ggsave geom_violin scale_color_gradient element_line theme_linedraw scale_fill_manual scale_color_manual aes geom_histogram element_rect geom_point xlab ylab ggtitle theme_bw theme_minimal theme element_text guides guide_legend geom_boxplot labs theme_classic element_blank geom_jitter position_jitter
+#' @importFrom ggplot2 ggplot ggsave geom_smooth geom_violin scale_color_gradient element_line theme_linedraw scale_fill_manual scale_color_manual aes geom_histogram element_rect geom_point xlab ylab ggtitle theme_bw theme_minimal theme element_text guides guide_legend geom_boxplot labs theme_classic element_blank geom_jitter position_jitter
 #' @importFrom VIM kNN
-#' @importFrom UniProt.ws mapUniProt
+#' @importFrom UniprotR GetProteinAnnontate
 #' @importFrom stringr str_extract
 #' @importFrom stats kruskal.test p.adjust prcomp sd wilcox.test friedman.test rnorm bartlett.test model.matrix heatmap median na.omit
 #' @importFrom forcats fct_inorder
 #' @importFrom vegan adonis2
 #' @importFrom limma topTable eBayes contrasts.fit normalizeCyclicLoess normalizeVSN lmFit normalizeQuantiles duplicateCorrelation
-#' @importFrom ComplexHeatmap HeatmapAnnotation anno_block draw Heatmap
+#' @importFrom pheatmap pheatmap
 #' @importFrom missRanger missRanger
 #' @importFrom car leveneTest
-#' @importFrom vsn meanSdPlot
 #'
 #' @examples
 #' #Example of running the function with paths for three groups.
 #'
+#'
 #' T1_path <- system.file("extdata", "PDexports(multiple_files)",
 #'  "T1_BLCA", package = "ProtE")
 #' T2_path <- system.file("extdata", "PDexports(multiple_files)",
 #' "T2_BLCA", package = "ProtE")
 #'
-#' pd_multi(T1_path, T2_path,
+#' temp_dir1 <- file.path(tempdir(), "T1_path")
+#' temp_dir2 <- file.path(tempdir(), "T2_path")
+#'
+#' dir.create(temp_dir1, recursive = TRUE, showWarnings = FALSE)
+#' dir.create(temp_dir2, recursive = TRUE, showWarnings = FALSE)
+#'
+#'
+#'
+#' excel_files1 <- list.files(T1_path, pattern = "\\.xlsx$", full.names = TRUE)
+#' excel_files2 <- list.files(T2_path, pattern = "\\.xlsx$", full.names = TRUE)
+#'
+#' file.copy(excel_files1, temp_dir1)
+#' file.copy(excel_files2, temp_dir2)
+#'
+#' pd_multi(temp_dir1, temp_dir2,
 #'          normalization = FALSE,
 #'          global_filtering = TRUE,  imputation = FALSE,
 #'          independent = TRUE)
@@ -63,7 +76,7 @@ pd_multi <- function(...,
                         significance = "p",
                      description = FALSE)
   {
-   Sample=group1= Accession =Description =Symbol =X =Y =df4_wide= percentage=variable =.= g1.name =g2.name=key =value = NULL
+   Sample=group1= Accession =Description =Symbol =X = Mean = SD =Y =df4_wide= percentage=variable =.= g1.name =g2.name=key =value = NULL
 message("The ProtE process starts now!")
 group_paths <- list(...)
 groups_number <- length(group_paths)
@@ -117,27 +130,14 @@ if ("Description" %in% colnames(dataspace)){
   }
   if (description == TRUE){
     "The Description fetching from UniProt starts now, it might take some time depending on you Network speed."
-    id_numbers <- dataspace$Accession
+    id_numbers <- dataspace$Protein.Ids
     for (j in 1:length(id_numbers)){id_numbers[j] <- stringr::str_extract(id_numbers[j], "^[^;]*")}
     df_description <- data.frame("Description" = character(), stringsAsFactors = FALSE)
-    metadata<-UniProt.ws::mapUniProt( from = "UniProtKB_AC-ID", to = "UniProtKB", columns = c("protein_name","organism_name","gene_names","protein_existence","sequence_version","id"), id_numbers,pageSize = 500L)
-    df_number_ids<-as.data.frame(id_numbers)
-    fixed_data<-dplyr::left_join(df_number_ids,metadata,by=c("id_numbers"="From"))
+    dataspace$Protein.Ids<-id_numbers
+    conv_ID <- GetProteinAnnontate(dataspace$Protein.Ids, columns =c("organism_name"	, "protein_name"	, "id"	,"gene_names") )
+    details<-paste(conv_ID$Protein.names," OS=",conv_ID$Organism," GN=",conv_ID$Gene.Names," -[",conv_ID$Entry.Name,"]")
+    df_description <- rbind(df_description, data.frame(Description = details, stringsAsFactors = FALSE))
 
-    for (i in 1:nrow( fixed_data)){
-      organism<- fixed_data$Organism[i]
-      gene<-stringr::str_extract(fixed_data$Gene.Names[i], "^[^ ]*")
-      entry_name<- fixed_data$Entry.Name[i]
-      protein_name<- fixed_data$Protein.names[i]
-      sv<- fixed_data$Sequence.version[i]
-      if (fixed_data$Protein.existence[i]=="Evidence at protein level"){pe<-1}
-      if (fixed_data$Protein.existence[i]=="Evidence at transcript level"){pe<-2}
-      if (fixed_data$Protein.existence[i]=="Inferred by homology"){pe<-3}
-      if (fixed_data$Protein.existence[i]=="Predicted") {pe<-4}
-      if (fixed_data$Protein.existence[i]=="Uncertain") {pe<-5}
-      details<-paste(protein_name," OS=",organism," GN=",gene," PE=",pe," SV=",sv," -[",entry_name,"]")
-      df_description <- rbind(df_description, data.frame(Description = details, stringsAsFactors = FALSE))
-    }
 
     dataspace<-cbind(dataspace[,1],df_description,dataspace[,2:ncol(dataspace)])
   }
@@ -259,19 +259,37 @@ openxlsx::write.xlsx(dataspace, file = mt_file_path)
 
     if (normalization %in% c(FALSE,"median", "Total_Ion_Current", "PPM") ){
       log.dataspace <- log(dataspace[,-c(1:2)]+1,2)
-    sdrankplot_path <- file.path(path_resplot, "meanSdPlot.bmp")
-      bmp(sdrankplot_path,width = 1500, height = 1080, res = 150)
-      suppressWarnings(vsn::meanSdPlot(as.matrix(log.dataspace[, -1:-2])))
-      dev.off()
+      row_means <- rowMeans(log.dataspace, na.rm = TRUE)
+      row_sds <- apply(log.dataspace, 1, sd, na.rm = TRUE)
+      plot_data <- data.frame(Mean = row_means, SD = row_sds)
+      meansd <- ggplot(plot_data, aes(x = Mean, y = SD)) +
+        geom_point(alpha = 0.5, color = "blue") +
+      suppressMessages(geom_smooth(method = "loess", color = "red", se = FALSE)) +
+        theme_minimal() +
+        labs(title = "Mean-SD Plot on the log2 normalized data", x = "Mean Expression", y = "Standard Deviation")
+      meansd
+      ggplot2::ggsave("meanSdPlot.bmp", plot = meansd,  path = path_resplot,
+                      scale = 1, width = 5, height = 4, units = "in",
+                      dpi = 300, limitsize = TRUE)
+
       message("Creating Mean-SD plot on the log2 data.")
     } else {
-      sdrankplot_path <- file.path(path_resplot, "meanSdPlot.bmp")
-      bmp(sdrankplot_path,width = 1500, height = 1080, res = 150)
-      suppressWarnings(vsn::meanSdPlot(as.matrix(dataspace[, -1:-2])))
-      dev.off()
+      row_means <- rowMeans(dataspace[,-c(1,2)], na.rm = TRUE)
+      row_sds <- apply(dataspace[,-c(1,2)], 1, sd, na.rm = TRUE)
+      plot_data <- data.frame(Mean = row_means, SD = row_sds)
+      meansd <- ggplot(plot_data, aes(x = Mean, y = SD)) +
+        geom_point(alpha = 0.5, color = "blue") +
+        geom_smooth(method = "loess", color = "red", se = FALSE) +
+        theme_minimal() +
+        labs(title = "Mean-SD Plot on the log2 normalized data", x = "Mean Expression", y = "Standard Deviation")
+      meansd
+      ggplot2::ggsave("meanSdPlot.bmp", plot = meansd,  path = path_resplot,
+                      scale = 1, width = 5, height = 4, units = "in",
+                      dpi = 300, limitsize = TRUE)
       message("Creating Mean-SD plot.")
     }
 
+
 name_dataspace <-  dataspace[, -1:-2]
     dat.dataspace<-dataspace
 
@@ -851,26 +869,26 @@ if (global_filtering == TRUE) {
 
       range_limit <- min(abs(min(zlog.dataspace.sig, na.rm = TRUE)), abs(max(zlog.dataspace.sig, na.rm = TRUE)))
 
-      mycols <- circlize::colorRamp2(
-        c(-range_limit, 0, range_limit),
-        c("blue", "white", "red")
-      )
-      heatmap_data<- ComplexHeatmap::Heatmap(as.matrix(zlog.dataspace.sig),
-                                             cluster_rows = TRUE,
-                                             cluster_columns = FALSE,
-                                             show_row_names = FALSE,
-                                             show_column_names = FALSE,
-                                             column_split = groups_list_f,
-                                             top_annotation = ComplexHeatmap::HeatmapAnnotation(foo = anno_block(gp = gpar(fill = 2:(groups_number+1)),
-                                                                                                                 labels = group_names, labels_gp = gpar(col = "black", fontsize = 10))),
-                                             col = mycols, column_title = NULL,
-                                             heatmap_legend_param = list(
-                                               title = "Z-Score",
-                                               color_bar = "continuous"
-                                             ))
+      breaks <- seq(-range_limit, range_limit, length.out = 101)
+      mycols_vector <- grDevices::colorRampPalette(c("blue", "white", "red"))(100)
+
+      annotation_col <- data.frame(Group = factor(groups_list_f))
+      rownames(annotation_col) <- colnames(zlog.dataspace.sig)
+      colnames(annotation_col) <- " "
       bmp_file_path <- file.path(path_resplot, "heatmap.bmp")
       bmp(bmp_file_path,width = 1500, height = 1080, res = 150)
-      ComplexHeatmap::draw(heatmap_data)
+      pheatmap(as.matrix(zlog.dataspace.sig),
+               cluster_rows = TRUE,
+               cluster_cols = FALSE,
+               show_rownames = FALSE,
+               show_colnames = FALSE,
+               annotation_col = annotation_col,
+               color = mycols_vector,
+               breaks = breaks,
+               legend = TRUE,
+               legend_labels = NULL,
+               annotation_legend = TRUE,
+               scale = "none")
       dev.off()
 
       message("A heatmap with the differentially expressed proteins was created as heatmap.bmp")
